<?php
/**
 * Magento Status Bar Section - Magento Module
 * This demonstrates main content area injection
 * Location: Main - Before Tabs anchor point
 */

use yii\helpers\Html;
?>

<div class="progress-container mb-4">
    <h6 class="mb-2">
        <i class="fab fa-magento mr-2"></i>
        Magento Integration Status
    </h6>
    
    <div class="progress mb-2" style="height: 25px;">
        <div class="progress-bar bg-success progress-bar-striped" 
             role="progressbar" 
             style="width: 75%" 
             aria-valuenow="75" 
             aria-valuemin="0" 
             aria-valuemax="100">
            Order Synced (75%)
        </div>
    </div>
    
    <div class="row">
        <div class="col-md-3">
            <div class="text-center">
                <i class="fas fa-check-circle text-success fa-2x"></i>
                <div class="mt-1">
                    <small class="text-muted">Order Created</small>
                </div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="text-center">
                <i class="fas fa-check-circle text-success fa-2x"></i>
                <div class="mt-1">
                    <small class="text-muted">Inventory Reserved</small>
                </div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="text-center">
                <i class="fas fa-check-circle text-success fa-2x"></i>
                <div class="mt-1">
                    <small class="text-muted">Payment Processed</small>
                </div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="text-center">
                <i class="fas fa-clock text-warning fa-2x"></i>
                <div class="mt-1">
                    <small class="text-muted">Pending Shipment</small>
                </div>
            </div>
        </div>
    </div>
</div>